@@ -58,6 +58,8 @@ static QString KEY_JAVASCRIPT_ON = SETTINGS_GROUP + "/" + "javascript_on";
 static QString KEY_REMOTE_ON = SETTINGS_GROUP + "/" + "remote_on";
 static QString KEY_USE_PRETTIFY = SETTINGS_GROUP + "/" + "use_prettify";
 static QString KEY_USE_WSPREWRAP = SETTINGS_GROUP + "/" + "use_white_space_pre_wrap";
+static QString KEY_SKIP_PRINT_WARNINGS = SETTINGS_GROUP + "/" + "skipprintwarnings";
+static QString KEY_SKIP_PRINT_PREVIEW = SETTINGS_GROUP + "/" + "skipprintpreview";
 
 
 SettingsStore::SettingsStore()
@@ -203,6 +205,18 @@ int SettingsStore::useWSPreWrap()
   return value(KEY_USE_WSPREWRAP, 0).toInt();
 }
 
+bool SettingsStore::skipPrintWarnings()
+{
+  clearSettingsGroup();
+  return value(KEY_SKIP_PRINT_WARNINGS, false).toBool();
+}
+
+bool SettingsStore::skipPrintPreview()
+{
+  clearSettingsGroup();
+  return value(KEY_SKIP_PRINT_PREVIEW, false).toBool();
+}
+
 void SettingsStore::setUILanguage(const QString &language_code)
 {
     clearSettingsGroup();
@@ -328,6 +342,18 @@ void SettingsStore::setUseWSPreWrap(int on)
   setValue(KEY_USE_WSPREWRAP, on);
 }
 
+void SettingsStore::setSkipPrintWarnings(bool skip)
+{
+  clearSettingsGroup();
+  return setValue(KEY_SKIP_PRINT_WARNINGS, skip);
+}
+
+void SettingsStore::setSkipPrintPreview(bool skip)
+{
+  clearSettingsGroup();
+  return setValue(KEY_SKIP_PRINT_PREVIEW, skip);
+}
+
 void SettingsStore::clearAppearanceSettings()
 {
     clearSettingsGroup();
@@ -338,6 +364,7 @@ void SettingsStore::clearAppearanceSettings()
     remove(KEY_SPECIAL_CHARACTER_FONT_FAMILY);
     remove(KEY_SPECIAL_CHARACTER_FONT_SIZE);
     remove(KEY_MAIN_MENU_ICON_SIZE);
+    remove(KEY_SKIP_PRINT_WARNINGS);
 }
 
 void SettingsStore::clearSettingsGroup()
