@@ -121,6 +121,10 @@ public:
 
     int useWSPreWrap();
 
+    bool skipPrintWarnings();
+
+    bool skipPrintPreview();
+
 public slots:
 
     /**
@@ -178,6 +182,10 @@ public slots:
 
     void setUseWSPreWrap(int on);
 
+    void setSkipPrintWarnings(bool skip);
+
+    void setSkipPrintPreview(bool skip);
+
 private:
     /**
      * Ensures there is not an open settings group which will cause the settings
