@@ -1191,7 +1191,7 @@ Si une traduction pour un mot ou une phrase spécifique n&apos;est pas disponibl
         <location filename="../MainWindow.cpp" line="1235"/>
         <location filename="../MainWindow.cpp" line="1236"/>
         <source>HTML files (*.htm *.html *.xhtml)</source>
-        <translation>Fichiers HTML (*. htm *. html *. xhtml)</translation>
+        <translation>Fichiers XHTML (*.htm *.html *.xhtml)</translation>
     </message>
     <message>
         <location filename="../MainWindow.cpp" line="1226"/>
